<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://metomic.io
 * @since      1.0.0
 *
 * @package    Metomic
 * @subpackage Metomic/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Metomic
 * @subpackage Metomic/public
 * @author     Anosh Malik <anosh@metomic.io>
 */
class Metomic_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $metomic    The ID of this plugin.
	 */
	private $metomic;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $metomic       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $metomic, $version ) {

		$this->metomic = $metomic;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Metomic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Metomic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->metomic, plugin_dir_url( __FILE__ ) . 'css/metomic-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Metomic_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Metomic_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$projectId = get_option('mtm_project_id', '');
        $domain = site_url();
		if (!empty(trim($projectId))) {
            wp_enqueue_script( 'metomic-config', "https://config.metomic.io/config.js?id=$projectId", array( 'jquery' ), $this->version, false );
		} else {
            wp_enqueue_script( 'metomic-config', "https://config.metomic.io/config.js?id=$domain", array( 'jquery' ), $this->version, false );
        }
        wp_enqueue_script( $this->metomic, "https://consent-manager.metomic.io/embed.js", array( 'jquery' ), $this->version, false );

	}
}
